local mod = ...

--[[

	Adds poultry yards that produce poultry meat and eggs, early and cheap food.
	Also produces dung for vegetable gardens.

]]--


-- Job -------------------------------------------------------------------------------------
mod:register({
	DataType = "JOB",
	Id = "POULTRYFARMER_JOB",
	JobName = "POULTRYFARMER_JOB_NAME",
	JobDescription = "POULTRYFARMER_JOB_DESC",
	IsLockedByDefault = false,
	DefaultBehavior = "BEHAVIOR_WORK",
	-- UseWorkplaceBehavior = true,
    ProductionDelay = 80.0, -- default 30
	AssetJobProgression = "DEFAULT_JOB_PROGRESSION",
	CharacterSetup = {
		DataType = "CHARACTER_SETUP",
			RightHandObject = {
				Model = "PREFAB_TOOL_SHEPHERD_STICK"
				-- WorkAttachName = "SeedBag_Anchor", 
				-- WalkAttachName = "SeedBag_Anchor"
			},
		IdleAnimation = "GUARD"
	}
})

mod:override({
    Id = "NEWCOMER",
    CompatibleJobList = {
        Action = "APPEND",
        "POULTRYFARMER_JOB"
    }
})

mod:override({
    Id = "SERF",
    CompatibleJobList = {
        Action = "APPEND",
        "POULTRYFARMER_JOB"
    }
})



-- Resource -------------------------------------------------------------------------------------

mod:registerAssetId("icons/Chicken.png", "ICON_CHICKEN")

mod:register({
	DataType = "RESOURCE",
	Id = "CHICKEN_RESOURCE",
	ResourceName = "CHICKEN_RESOURCE_NAME",
	OrderId = 1,
	Icon = "ICON_CHICKEN",
	ResourceTypeList = { "FOOD", "POULTRYFARM_POULTRY_RESOURCE_TYPE" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 10 },
	DisplayInInventory = true
})

mod:registerAssetId("icons/Egg.png", "ICON_EGG")

mod:override({
	Id = "BV1_EGG",
	ResourceName = "EGG_RESOURCE_NAME",
	OrderId = 1,
	Icon = "ICON_EGG",
	ResourceTypeList = { "FOOD", "POULTRYFARM_EGG_RESOURCE_TYPE" },
	IsTradable = true,
	ResourceLayoutType = "CRATES",
	VillagerBuyingPrice = { Resource = "GOLD", Quantity = 8 },
	DisplayInInventory = true
})



-- Resource Type: Vegetable Farm
mod:registerEnumValue( "RESOURCE_TYPE", "POULTRYFARM_RESOURCE_TYPE" )
mod:registerEnumValue( "RESOURCE_TYPE", "POULTRYFARM_POULTRY_RESOURCE_TYPE" )
mod:registerEnumValue( "RESOURCE_TYPE", "POULTRYFARM_EGG_RESOURCE_TYPE" )



-- Building part type
mod:registerEnumValue("BUILDING_PART_TYPE", "COUNTER")



-- Assets
mod:registerAssetId("models/ChickenYard1.fbx/Prefab/ChickenYardPart/Chicken.001", "PREFAB_CHICKEN")

mod:registerAssetId("models/ChickenYard1.fbx/Prefab/ChickenYardPart", "PREFAB_CHICKENYARD1")
mod:registerAssetId("models/ChickenYard2.fbx/Prefab/ChickenYardPart", "PREFAB_CHICKENYARD2")

mod:registerAssetId("models/Dovecote1.fbx/Prefab/DovecotePart", "PREFAB_DOVECOTE1")
mod:registerAssetId("models/Dovecote2.fbx/Prefab/DovecotePart", "PREFAB_DOVECOTE2")
mod:registerAssetId("models/Dovecote3.fbx/Prefab/DovecotePart", "PREFAB_DOVECOTE3")

mod:registerAssetId("models/GoosePen1.fbx/Prefab/GoosePenPart", "PREFAB_GOOSEPEN1")
mod:registerAssetId("models/GoosePen2.fbx/Prefab/GoosePenPart", "PREFAB_GOOSEPEN2")

mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartPart", "PREFAB_POULTRYCART")
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartEggPart", "PREFAB_POULTRYCART_EGG")



-- Building Asset Processor
mod:registerAssetProcessor("models/ChickenYard1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/ChickenYard2.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })

mod:registerAssetProcessor("models/Dovecote1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/Dovecote2.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/Dovecote3.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })

mod:registerAssetProcessor("models/GoosePen1.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })
mod:registerAssetProcessor("models/GoosePen2.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })

mod:registerAssetProcessor("models/PoultryCart.fbx", { DataType = "BUILDING_ASSET_PROCESSOR" })



-- Construction visual
mod:registerAssetId("models/ChickenYard1.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_CHICKENYARD1")
mod:registerAssetId("models/ChickenYard2.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_CHICKENYARD2")

mod:registerAssetId("models/Dovecote1.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_DOVECOTE1")
mod:registerAssetId("models/Dovecote2.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_DOVECOTE2")
mod:registerAssetId("models/Dovecote3.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_DOVECOTE3")

mod:registerAssetId("models/GoosePen1.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_GOOSEPEN1")
mod:registerAssetId("models/GoosePen2.fbx/Prefab/ConstructionSteps", "PREFAB_CONSTR_GOOSEPEN2")



-- Collider Platform (climbable mesh)  -------------------------------------------------------------------------------------
mod:configurePrefabFlagList("models/Dovecote1.fbx/Prefab/DovecotePart", { "PLATFORM" })
mod:configurePrefabFlagList("models/Dovecote2.fbx/Prefab/DovecotePart", { "PLATFORM" })
mod:configurePrefabFlagList("models/Dovecote3.fbx/Prefab/DovecotePart", { "PLATFORM" })

mod:configurePrefabFlagList("models/GoosePen1.fbx/Prefab/GoosePenPart", { "PLATFORM" })



-- Grounding construction visuals
for i=1, 5, 1 do
	mod:registerPrefabComponent("models/ChickenYard1.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/ChickenYard2.fbx/Prefab/ConstructionSteps/Step_0." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Grounding fences
for i=1, 11, 1 do
	mod:registerPrefabComponent("models/ChickenYard1.fbx/Prefab/ChickenYardPart/Fence." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Grounding chickens and geese
for i=1, 8, 1 do
	mod:registerPrefabComponent("models/GoosePen2.fbx/Prefab/GoosePenPart/Goose." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end

for i=1, 9, 1 do
	mod:registerPrefabComponent("models/ChickenYard1.fbx/Prefab/ChickenYardPart/Chicken." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
	mod:registerPrefabComponent("models/ChickenYard2.fbx/Prefab/ChickenYardPart/Chicken." .. string.sub("000" .. i, -3), {DataType = "COMP_GROUNDED"})
end



-- Grounding General
mod:registerPrefabComponent("models/ChickenYard1.fbx/Prefab/ChickenYardPart/House.001", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/ChickenYard2.fbx/Prefab/ChickenYardPart/House.001", {DataType = "COMP_GROUNDED"})

mod:registerPrefabComponent("models/ChickenYard1.fbx/Prefab/ChickenYardPart/StumpAxe", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/ChickenYard2.fbx/Prefab/ChickenYardPart/StumpAxe", {DataType = "COMP_GROUNDED"})

mod:registerPrefabComponent("models/PoultryCart.fbx/Prefab/CartPart", {DataType = "COMP_GROUNDED"})
mod:registerPrefabComponent("models/PoultryCart.fbx/Prefab/CartEggPart", {DataType = "COMP_GROUNDED"})



-- Paths: Poultry cart -------------------------------------------------------------------------------------
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartPart/PATH_E_1", "PATH_POULTRYCART_E1")
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartPart/PATH_F_1", "PATH_POULTRYCART_F1")
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartPart/PATH_G_1", "PATH_POULTRYCART_G1")
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartPart/PATH_H_1", "PATH_POULTRYCART_H1")

mod:registerPrefabComponent("models/PoultryCart.fbx/Prefab/CartPart", {
    DataType = "COMP_BUILDING_PART",
    PathList = {
        {
            PathType = BUILDING_PATH_TYPE.DEFAULT,
            WayPointList = { "PATH_POULTRYCART_G1" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "PATH_POULTRYCART_E1" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "PATH_POULTRYCART_F1" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "PATH_POULTRYCART_H1" }
        },
    }
})



-- Paths: Egg cart -------------------------------------------------------------------------------------
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartEggPart/PATH_A_1", "PATH_EGGCART_A1")
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartEggPart/PATH_B_1", "PATH_EGGCART_B1")
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartEggPart/PATH_C_1", "PATH_EGGCART_C1")
mod:registerAssetId("models/PoultryCart.fbx/Prefab/CartEggPart/PATH_D_1", "PATH_EGGCART_D1")

mod:registerPrefabComponent("models/PoultryCart.fbx/Prefab/CartEggPart", {
    DataType = "COMP_BUILDING_PART",
    PathList = {
        {
            PathType = BUILDING_PATH_TYPE.DEFAULT,
            WayPointList = { "PATH_EGGCART_C1" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "PATH_EGGCART_A1" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "PATH_EGGCART_B1" }
        },
        {
            PathType = BUILDING_PATH_TYPE.PICKUP,
            WayPointList = { "PATH_EGGCART_D1" }
        },
    }
})



-- Building Function Assignable  -------------------------------------------------------------------------------------
mod:register({
    DataType = "BUILDING_FUNCTION_ASSIGNABLE",
    Id = "CHICKENYARD_FUNCTION_ASSIGNABLE",
	Name = "CHICKENYARD_FUNCTION_ASSIGNABLE_NAME",
	AuthorizedFunctionList = "CHICKENYARD_FUNCTION_LIST"
})



-- Building Function List  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_LIST",
    Id = "CHICKENYARD_FUNCTION_LIST",
	AssetFunctionList = {
		"CHICKENYARD_FUNCTION",
		"CHICKENYARD_CHICKEN_FUNCTION",
		"CHICKENYARD_EGGS_FUNCTION",
	}
})



-- Building Function: Poultry meat and eggs  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "CHICKENYARD_FUNCTION",
    Name = "CHICKENYARD_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "POULTRYFARMER_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "WATER", Quantity = 5 }
	},
    ResourceListNeeded = {
		{ Resource = "WATER", Quantity = 1 }
	},
    ResourceProduced = {
		{ Resource = "CHICKEN_RESOURCE", Quantity = 1 },
		{ Resource = "BV1_EGG", Quantity = 1 },
		{ Resource = "DUNG_RESOURCE", Quantity = 1 }
	}
})



-- Building Function: Poultry meat  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "CHICKENYARD_CHICKEN_FUNCTION",
    Name = "CHICKENYARD_CHICKEN_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "POULTRYFARMER_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "WATER", Quantity = 5 }
	},
    ResourceListNeeded = {
		{ Resource = "WATER", Quantity = 1 }
	},
    ResourceProduced = {
		{ Resource = "CHICKEN_RESOURCE", Quantity = 1 },
		{ Resource = "DUNG_RESOURCE", Quantity = 1 }
	}
})



-- Building Function: Poultry eggs  -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_WORKPLACE",
    Id = "CHICKENYARD_EGGS_FUNCTION",
    Name = "CHICKENYARD_EGGS_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "POULTRYFARMER_JOB", 
        Behavior = "BEHAVIOR_WORK"
    },
    InputInventoryCapacity = {
		{ Resource = "WATER", Quantity = 5 }
	},
    ResourceListNeeded = {
		{ Resource = "WATER", Quantity = 1 }
	},
    ResourceProduced = {
		{ Resource = "BV1_EGG", Quantity = 1 },
		{ Resource = "DUNG_RESOURCE", Quantity = 1 }
	}
})



-- Building Function: Poultry Cart (sell directly to villagers) -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_MARKET",
    Id = "POULTRYCART_FUNCTION",
    Name = "POULTRYCART_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "MARKET_TENDER", 
        Behavior = "BEHAVIOR_WORK"
    },
	TypeList = { "POULTRYFARM_POULTRY_RESOURCE_TYPE" },
	IsOverrideCapacity = true,
	CapacityPerSlot = 50,
	InputInventoryCapacity = {
		{ Resource = "CHICKEN_RESOURCE", Quantity = 25 },
	},
    ResourceListNeeded = {
		{ Resource = "CHICKEN_RESOURCE", Quantity = 10 },
	},
	ResourceProduced = {
		{ Resource = "CHICKEN_RESOURCE", Quantity = 10 },
	}
})



-- Building Function: Egg Cart (sell directly to villagers) -------------------------------------------------------------------------------------

mod:register({
    DataType = "BUILDING_FUNCTION_MARKET",
    Id = "POULTRYCART_EGG_FUNCTION",
    Name = "POULTRYCART_EGG_FUNCTION_NAME",
    WorkerCapacity = 1,
    RelatedJob = { 
        Job = "MARKET_TENDER", 
        Behavior = "BEHAVIOR_WORK"
    },
	TypeList = { "POULTRYFARM_EGG_RESOURCE_TYPE" },
	IsOverrideCapacity = true,
	CapacityPerSlot = 50,
	InputInventoryCapacity = {
		{ Resource = "BV1_EGG", Quantity = 25 },
	},
    ResourceListNeeded = {
		{ Resource = "BV1_EGG", Quantity = 10 },
	},
	ResourceProduced = {
		{ Resource = "BV1_EGG", Quantity = 10 },
	}
})




-- Building Part: Placeholder chicken used to place the initial instance of the farm -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHICKEN_PART",
	Name = "CHICKENYARD_NAME", 
	Description = "CHICKENYARD_DESC",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHICKEN"
	},
	IsVisibleWhenBuilt = false
})



-- Building: Poultry farm -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING", 
	Id = "CHICKENYARD",
	Name = "CHICKENYARD_NAME",
	Description = "CHICKENYARD_DESC",
	BuildingType = "GENERAL",
	AssetCoreBuildingPart = "CHICKEN_PART",
	BuildingPartSetList = {
		{
			Name = "CHICKENYARD_SET_NAME",
			BuildingPartList = { 
				"CHICKENYARD1_PART",
				"CHICKENYARD2_PART"
			}
		}, 
		{
			Name = "DOVECOTE_SET_NAME",
			BuildingPartList = { 
				"DOVECOTE1_PART",
				"DOVECOTE2_PART",
				"DOVECOTE3_PART"
			}
		}, 
		{
			Name = "GOOSEPEN_SET_NAME",
			BuildingPartList = { 
				"GOOSEPEN1_PART",
				"GOOSEPEN2_PART"
			}
		},
		{
			Name = "MARKET_SET_NAME",
			BuildingPartList = { 
				"POULTRYCART_PART",
				"POULTRYCART_EGG_PART",
			}
		}
	},	
	RequiredPartList = {
		{ Category = "CORE", Quantity = 1 }
	},
	IsEditable = true
})



-- Building Part: Chicken yard (fenced) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHICKENYARD1_PART",
	Name = "CHICKENYARD1_PART_NAME", 
	Description = "CHICKENYARD1_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHICKENYARD1"
	},
	ConstructionVisual = "PREFAB_CONSTR_CHICKENYARD1",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {5.5, 5.5}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_FUNCTION_ASSIGNABLE",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "PLANK", Quantity = 4 }
		}
	}
})



-- Building Part: Chicken yard (unfenced) -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "CHICKENYARD2_PART",
	Name = "CHICKENYARD2_PART_NAME", 
	Description = "CHICKENYARD2_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_CHICKENYARD2"
	},
	ConstructionVisual = "PREFAB_CONSTR_CHICKENYARD2",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 4, {0.0, 0.0}, 12 ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_FUNCTION_ASSIGNABLE",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "PLANK", Quantity = 4 }
		}
	}
})



-- Building Part: Dovecote 1: raised wooden box -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING_PART",
	Id = "DOVECOTE1_PART",
	Name = "DOVECOTE1_PART_NAME", 
	Description = "DOVECOTE1_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_DOVECOTE1"
	},
	ConstructionVisual = "PREFAB_CONSTR_DOVECOTE1",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {3.6, 3.6}, {0, 0} ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
			}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_FUNCTION_ASSIGNABLE",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 2 },
            { Resource = "PLANK", Quantity = 6 }
		}
	}
})



-- Building Part: Dovecote 2: stone silo -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING_PART",
	Id = "DOVECOTE2_PART",
	Name = "DOVECOTE2_PART_NAME", 
	Description = "DOVECOTE2_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_DOVECOTE2"
	},
	ConstructionVisual = "PREFAB_CONSTR_DOVECOTE2",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 2.75, {0, 0}, 14 ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}, 
            { 
                Polygon = polygon.createCircle( 1.75, {0, 3.5}, 6 ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_FUNCTION_ASSIGNABLE",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 2 },
            { Resource = "STONE", Quantity = 10 }
		}
	}
})



-- Building Part: Dovecote 3: wood silo -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING_PART",
	Id = "DOVECOTE3_PART",
	Name = "DOVECOTE3_PART_NAME", 
	Description = "DOVECOTE3_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_DOVECOTE3"
	},
	ConstructionVisual = "PREFAB_CONSTR_DOVECOTE3",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {3.7, 3.7}, {0, 0} ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}, 
            { 
                Polygon = polygon.createRectangle( {1.5, 2.5}, {0, 2.75} ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_FUNCTION_ASSIGNABLE",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 },
            { Resource = "PLANK", Quantity = 4 },
            { Resource = "STONE", Quantity = 2 }
		}
	}
})



-- Building Part: Goose Pen 1: fenced with hill -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING_PART",
	Id = "GOOSEPEN1_PART",
	Name = "GOOSEPEN1_PART_NAME", 
	Description = "GOOSEPEN1_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_GOOSEPEN1"
	},
	ConstructionVisual = "PREFAB_CONSTR_GOOSEPEN1",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 5, {0, 0}, 16 ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
			}, 
            { 
                Polygon = polygon.createCircle( 3.5, {0, 0}, 16 ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_FUNCTION_ASSIGNABLE",
	Cost = {
		RessourcesNeeded = {
            { Resource = "WOOD", Quantity = 4 }
		}
	}
})



-- Building Part: Goose Pen 2: unfenced, no hill -------------------------------------------------------------------------------------

mod:register({
	DataType = "BUILDING_PART",
	Id = "GOOSEPEN2_PART",
	Name = "GOOSEPEN2_PART_NAME", 
	Description = "GOOSEPEN2_PART_DESC", 
	Category = "CORE", 
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_GOOSEPEN2"
	},
	ConstructionVisual = "PREFAB_CONSTR_GOOSEPEN2",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createCircle( 2.25, {0, 0}, 16 ),
                Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = false } 
			}
		}
	},
	AssetBuildingFunction = "CHICKENYARD_FUNCTION_ASSIGNABLE",
	Cost = {
		RessourcesNeeded = {
            -- { Resource = "WOOD", Quantity = 4 }
		}
	}
})




-- Building Part: Poultry Cart -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "POULTRYCART_PART",
	Name = "POULTRYCART_PART_NAME", 
	Category = "COUNTER",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_POULTRYCART"
	},
	-- ConstructionVisual = "PREFAB_CONSTR_BUTCHERCOUNTER",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {2, 1.5}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "POULTRYCART_FUNCTION",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 1 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 1 } },
		RessourcesNeeded = {
            { Resource = "PLANK", Quantity = 2 }
		}
	},
	DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "ADD",
		Radius = 15.0,
		Value = 0.5
	} }
})



-- Building Part: Poultry Cart -------------------------------------------------------------------------------------
mod:register({
	DataType = "BUILDING_PART",
	Id = "POULTRYCART_EGG_PART",
	Name = "POULTRYCART_EGG_PART_NAME", 
	Category = "COUNTER",
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = "PREFAB_POULTRYCART_EGG"
	},
	-- ConstructionVisual = "PREFAB_CONSTR_BUTCHERCOUNTER",
	BuildingZone = { 
        ZoneEntryList = {
            { 
                Polygon = polygon.createRectangle( {2, 1.5}, {0.0, 0.0} ),
                Type = { DEFAULT = true, NAVIGABLE = true, GRASS_CLEAR = true } 
			}
		}
	},
	AssetBuildingFunction = "POULTRYCART_EGG_FUNCTION",
	Cost = {
		BuildRightTaxes = {	{ Resource = "GOLD", Quantity = 1 } },
		UpkeepCost = { { Resource = "GOLD", Quantity = 1 } },
		RessourcesNeeded = {
            { Resource = "PLANK", Quantity = 2 }
		}
	},
	DesirabilityModifiers = { {
		Desirability = "DESIRABILITY_RESIDENTIAL",
		Type = "ADD",
		Radius = 15.0,
		Value = 0.5
	} }
})
